@@ -47,6 +47,7 @@ class AdvancedPowerMaemo5(StatusMenuItem):
     self.__lcl = get_locale()
 
     self.launching_apm = False
+    self.__discharging = True
 
     self.__status_menu_item = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL, self.app_name, 'Waiting for APMD')
     self.__status_menu_item.set_image(gtk.Image())
@@ -146,6 +147,7 @@ class AdvancedPowerMaemo5(StatusMenuItem):
   def handle_battery_status(self, key):
     battery_state = '%s: %s' % (self.__lcl.get_item('timeleft'), self.__lcl.get('unknown'))
     battery_value = '%s: %s' % (self.__lcl.get_item('battery_status'), u'\u221E')
+    self.__discharging = False
     state = self.monitor.get_battery_state()
     if state == 'charging':
       battery_state = self.__lcl.get_item('%s_%s' % (key, state))
@@ -162,10 +164,10 @@ class AdvancedPowerMaemo5(StatusMenuItem):
         battery_state = self.__lcl.get_item('%s_%s' % (key, state))
         HildonBanner.show_information(self.__status_menu_item, battery_state)
       else:
+        self.__discharging = True
         battery_value = self.update_battery_view(state)
     self.__status_menu_item.set_text(battery_value, battery_state)
-    if state not in ('charging', 'full', 'charger_disconn'):
-      self.update_timeleft()
+    self.update_timeleft()
 
   def update_battery_view(self, state):
     battery_state = '%s: %s' % (self.__lcl.get_item('battery_status'), state)
@@ -203,9 +205,10 @@ class AdvancedPowerMaemo5(StatusMenuItem):
     self.update_timeleft()
 
   def update_timeleft(self):
-    if self.__info['timeleft_idle'] > 60:
-      self.__status_menu_item.set_value('%s: %s / %s:00' % (self.__lcl.get_item('timeleft'), get_formatted_time(self.__info['timeleft_active'], format=1), get_formatted_time(self.__info['timeleft_idle'], format=2)))
-    else:
-      self.__status_menu_item.set_value('%s: %s / %s' % (self.__lcl.get_item('timeleft'), get_formatted_time(self.__info['timeleft_active'], format=1), get_formatted_time(self.__info['timeleft_idle'], format=2)))
+    if self.__discharging:
+      if self.__info['timeleft_idle'] > 60:
+        self.__status_menu_item.set_value('%s: %s / %s:00' % (self.__lcl.get_item('timeleft'), get_formatted_time(self.__info['timeleft_active'], format=1), get_formatted_time(self.__info['timeleft_idle'], format=2)))
+      else:
+        self.__status_menu_item.set_value('%s: %s / %s' % (self.__lcl.get_item('timeleft'), get_formatted_time(self.__info['timeleft_active'], format=1), get_formatted_time(self.__info['timeleft_idle'], format=2)))
 
 def get_hd_plugin_type(): return AdvancedPowerMaemo5
