@@ -21,6 +21,8 @@ class APLocale(Locale):
       'item-battery_status_charging': 'Battery is charging',
       'item-battery_status_charger_disconn': 'Charger disconnected',
       'item-timeleft':  'Time left',
+      'item-settings-translators': 'Translators',
+      'item-settings-about': 'About',
       'unknown': 'unknown'
     }
 
